==> Crypt-URandom-MonkeyPatch-v0.1.1.tar.gz: Crypt-URandom-MonkeyPatch-v0.1.1/SECURITY.md <==
# Security Policy for the Crypt-URandom-MonkeyPatch distribution.

Report issues via email at: Robert Rothenberg <rrwo@cpan.org>.


This is the Security Policy for Crypt-URandom-MonkeyPatch.

This text is based on the CPAN Security Group's Guidelines for Adding
a Security Policy to Perl Distributions (version 1.0.0)
https://security.metacpan.org/docs/guides/security-policy-for-authors.html

# How to Report a Security Vulnerability

Security vulnerabilities can be reported by e-mail to the current
project maintainers at Robert Rothenberg <rrwo@cpan.org>.

Please include as many details as possible, including code samples
or test cases, so that we can reproduce the issue.  Check that your
report does not expose any sensitive data, such as passwords,
tokens, or personal information.

If you would like any help with triaging the issue, or if the issue
is being actively exploited, please copy the report to the CPAN
Security Group (CPANSec) at <cpan-security@security.metacpan.org>.

Please *do not* use the public issue reporting system on RT or
GitHub issues for reporting security vulnerabilities.

Please do not disclose the security vulnerability in public forums
until past any proposed date for public disclosure, or it has been
made public by the maintainers or CPANSec.  That includes patches or
pull requests.

For more information, see
[Report a Security Issue](https://security.metacpan.org/docs/report.html)
on the CPANSec website.

## Response to Reports

The maintainer(s) aim to acknowledge your security report as soon as
possible.  However, this project is maintained by a single person in
their spare time, and they cannot guarantee a rapid response.  If you
have not received a response from them within one week, then
please send a reminder to them and copy the report to CPANSec at
<cpan-security@security.metacpan.org>.

Please note that the initial response to your report will be an
acknowledgement, with a possible query for more information.  It
will not necessarily include any fixes for the issue.

The project maintainer(s) may forward this issue to the security
contacts for other projects where we believe it is relevant.  This
may include embedded libraries, system libraries, prerequisite
modules or downstream software that uses this software.

They may also forward this issue to CPANSec.

# Which Software This Policy Applies To

Any security vulnerabilities in Crypt-URandom-MonkeyPatch are covered by this policy.

Security vulnerabilities are considered anything that allows users
to execute unauthorised code, access unauthorised resources, or to
have an adverse impact on accessibility or performance of a system.

Security vulnerabilities in upstream software (embedded libraries,
prerequisite modules or system libraries, or in Perl), are not
covered by this policy unless they affect Crypt-URandom-MonkeyPatch, or Crypt-URandom-MonkeyPatch can
be used to exploit vulnerabilities in them.

Security vulnerabilities in downstream software (any software that
uses Crypt-URandom-MonkeyPatch, or plugins to it that are not included with the
Crypt-URandom-MonkeyPatch distribution) are not covered by this policy.

## Supported Versions of Crypt-URandom-MonkeyPatch

The maintainer(s) will only commit to releasing security fixes for
the latest version of Crypt-URandom-MonkeyPatch.

# Installation and Usage Issues

The distribution metadata specifies minimum versions of
prerequisites that are required for Crypt-URandom-MonkeyPatch to work.  However, some
of these prerequisites may have security vulnerabilities, and you
should ensure that you are using up-to-date versions of these
prerequisites.

Where security vulnerabilities are known, the metadata may indicate
newer versions as recommended.

## Usage

Please see the software documentation for further information.

==> Crypt-URandom-MonkeyPatch-v0.1.3.tar.gz: Crypt-URandom-MonkeyPatch-v0.1.3/SECURITY.md <==
# Security Policy for the Crypt-URandom-MonkeyPatch distribution.

Report security issues via the project
[Security Advisories](https://github.com/robrwo/perl-Crypt-URandom-MonkeyPatch/security/advisories).

This is the Security Policy for Crypt-URandom-MonkeyPatch.

The latest version of the Security Policy can be found in the
[git repository for Crypt-URandom-MonkeyPatch](https://github.com/robrwo/perl-Crypt-URandom-MonkeyPatch).

This text is based on the CPAN Security Group's Guidelines for Adding
a Security Policy to Perl Distributions (version 1.3.0)
https://security.metacpan.org/docs/guides/security-policy-for-authors.html

# How to Report a Security Vulnerability

Security vulnerabilities can be reported to the current Crypt-URandom-MonkeyPatch
maintainers via the project
[Security Advisories](https://github.com/robrwo/perl-Crypt-URandom-MonkeyPatch/security/advisories).

Please include as many details as possible, including code samples
or test cases, so that we can reproduce the issue.  Check that your
report does not expose any sensitive data, such as passwords,
tokens, or personal information.

If you would like any help with triaging the issue, or if the issue
is being actively exploited, please copy the report to the CPAN
Security Group (CPANSec) at <cpan-security@security.metacpan.org>.

Please *do not* use the public issue reporting system on RT or
GitHub issues for reporting security vulnerabilities.

Please do not disclose the security vulnerability in public forums
until past any proposed date for public disclosure, or it has been
made public by the maintainers or CPANSec.  That includes patches or
pull requests.

For more information, see
[Report a Security Issue](https://security.metacpan.org/docs/report.html)
on the CPANSec website.

## Response to Reports

The maintainer(s) aim to acknowledge your security report as soon as
possible.  However, this project is maintained by a single person in
their spare time, and they cannot guarantee a rapid response.  If you
have not received a response from them within 2 weeks, then
please send a reminder to them and copy the report to CPANSec at
<cpan-security@security.metacpan.org>.

Please note that the initial response to your report will be an
acknowledgement, with a possible query for more information.  It
will not necessarily include any fixes for the issue.

The project maintainer(s) may forward this issue to the security
contacts for other projects where we believe it is relevant.  This
may include embedded libraries, system libraries, prerequisite
modules or downstream software that uses this software.

They may also forward this issue to CPANSec.

# Which Software This Policy Applies To

Any security vulnerabilities in Crypt-URandom-MonkeyPatch are covered by this policy.

Security vulnerabilities in versions of any libraries that are
included in Crypt-URandom-MonkeyPatch are also covered by this policy.

Security vulnerabilities are considered anything that allows users
to execute unauthorised code, access unauthorised resources, or to
have an adverse impact on accessibility or performance of a system.

Security vulnerabilities in upstream software (prerequisite modules
or system libraries, or in Perl), are not covered by this policy
unless they affect Crypt-URandom-MonkeyPatch, or Crypt-URandom-MonkeyPatch can
be used to exploit vulnerabilities in them.

Security vulnerabilities in downstream software (any software that
uses Crypt-URandom-MonkeyPatch, or plugins to it that are not included with the
Crypt-URandom-MonkeyPatch distribution) are not covered by this policy.

## Supported Versions of Crypt-URandom-MonkeyPatch

The maintainer(s) will only commit to releasing security fixes for
the latest version of Crypt-URandom-MonkeyPatch.

# Installation and Usage Issues

The distribution metadata specifies minimum versions of
prerequisites that are required for Crypt-URandom-MonkeyPatch to work.  However, some
of these prerequisites may have security vulnerabilities, and you
should ensure that you are using up-to-date versions of these
prerequisites.

Where security vulnerabilities are known, the metadata may indicate
newer versions as recommended.

## Usage

Please see the software documentation for further information.
